/**********************************************************************
 *
 * browseaction.cpp -- 
 * Copyright (C) 1999  The New Zealand Digital Library Project
 *
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *********************************************************************/

#include "browseaction.h"

browseaction::browseaction(){

  cerr<<"initialising browseaction"<<endl;

  cgiarginfo arg_ainfo;
  arg_ainfo.shortname = "a";
  arg_ainfo.longname = "action";
  arg_ainfo.multiplechar = true;
  arg_ainfo.defaultstatus = cgiarginfo::weak;
  arg_ainfo.argdefault = "br";
  arg_ainfo.savedarginfo = cgiarginfo::must;
  argsinfo.addarginfo (NULL, arg_ainfo);

  //the first browsing criterion -- collection metadata types
  arg_ainfo.shortname = "b1";
  arg_ainfo.longname = "browse criterion 1";
  arg_ainfo.multiplechar = false;
  arg_ainfo.defaultstatus = cgiarginfo::weak;
  arg_ainfo.argdefault = "0";
  arg_ainfo.savedarginfo = cgiarginfo::must;
  argsinfo.addarginfo (NULL, arg_ainfo);
 
  //the second browsing criterion -- collection metadata types + none - meaning
  //only one browsing criterion.  None is the default.
  arg_ainfo.shortname = "b2";
  arg_ainfo.longname = "browse criterion 2";
  arg_ainfo.multiplechar = false;
  arg_ainfo.defaultstatus = cgiarginfo::weak;
  arg_ainfo.argdefault = "0";
  arg_ainfo.savedarginfo = cgiarginfo::must;
  argsinfo.addarginfo (NULL, arg_ainfo);
  
  //the number of documents to show per page -- if the box is empty then
  //only the most basic divisions are made (so, first letter for A-Z, year 
  //for date).
  arg_ainfo.shortname = "bnu";
  arg_ainfo.longname = "browse docs per page";
  arg_ainfo.multiplechar = true;
  arg_ainfo.defaultstatus = cgiarginfo::good;
  arg_ainfo.argdefault = "";
  arg_ainfo.savedarginfo = cgiarginfo::must;
  argsinfo.addarginfo (NULL, arg_ainfo);

  //The text to filter documents for browsing (only documents containing these 
  //words will be browsed).
  arg_ainfo.shortname = "bft";
  arg_ainfo.longname = "browse filter text";
  arg_ainfo.multiplechar = true;
  arg_ainfo.defaultstatus = cgiarginfo::none;
  arg_ainfo.argdefault = "";
  arg_ainfo.savedarginfo = cgiarginfo::must;
  argsinfo.addarginfo (NULL, arg_ainfo);


  //Whether all or just some of the words in the filter box have to be present
  //0 - any 1- all
  arg_ainfo.shortname = "bt";
  arg_ainfo.longname = "browse all or any";
  arg_ainfo.multiplechar = false;
  arg_ainfo.defaultstatus = cgiarginfo::weak;
  arg_ainfo.argdefault = "0";
  arg_ainfo.savedarginfo = cgiarginfo::must;
  argsinfo.addarginfo (NULL, arg_ainfo);
  
  cerr<<"constructor"<<endl;
}

browseaction::~browseaction(){}

bool browseaction::init (ostream &logout){
  cerr<<"init"<<endl;
  return true;
}

void browseaction::configure (const text_t &key, const text_tarray &cfgline){
}



bool browseaction::check_cgiargs (cgiargsinfoclass &/*argsinfo*/, cgiargsclass &/*args*/, 
				ostream &/*logout*/) {
  // don't want to check anything yet.
  //cerr<<"check_cgiargs"<<endl;
  return true;
}

  
void browseaction::get_cgihead_info (cgiargsclass &args, 
				     recptprotolistclass *protos,
				     response_t &response, 
				     text_t &response_data, 
				     ostream &logout){
  response = content;
  response_data = "text/html";

  //cerr<<"get_cgihead_info"<<endl;
}

void browseaction::define_internal_macros (displayclass &disp, 
					   cgiargsclass &args, 
					   recptprotolistclass *protos, 
					   ostream &logout){
  //cerr<<"define_internal_macros"<<endl;
}

void browseaction::define_external_macros (displayclass &disp, 
					   cgiargsclass &args, 
					   recptprotolistclass *protos, 
					   ostream &logout){
  //cerr<<"define_external_macros"<<endl;
}

bool browseaction::do_action (cgiargsclass &args, recptprotolistclass *protos, 
		browsermapclass *browsers, displayclass &disp, 
		outconvertclass &outconvert, ostream &textout, 
		ostream &logout){
  
  
  textout << outconvert << disp << "_browse:header_\n" <<"_browse:content_"
	  << "_browse:footer_";
  
  return true;
}









